@@ -388,6 +388,9 @@ class NotebookClient(LoggingConfigurable):
             except AttributeError:
                 raise AttributeError('self.km={} has no client() or get_kernel() method, '
                                      'what is this?'.format(self.km))
+            # since self.km is a MultiKernelManager, it might not be async
+            # so let's ensure the client is async
+            km.client_class = 'jupyter_client.asynchronous.AsyncKernelClient'
 
         self.kc = km.client()
         await ensure_async(self.kc.start_channels())
@@ -464,7 +467,7 @@ class NotebookClient(LoggingConfigurable):
             The executed notebook.
         """
         reset_kc = kwargs.get('reset_kc', False)
-        if reset_kc:
+        if reset_kc and self.km:
             await self._async_cleanup_kernel()
         self.reset_execution_trackers()
 
